biosaur2 - A feature detection LC-MS1 spectra. This project is a rewriten version of Biosaur software (https://github.com/abdrakhimov1/Biosaur).
-----------------------------------------------------------------------

The centroided mzML file is required for of the script.

Algorithm can be run with following command:

    biosaur2 path_to_MZML

The script output contains tsv table with peptide features.

Citing biosaur2
-------------------
Abdrakhimov, et al. Biosaur: An open-source Python software for liquid chromatography–mass spectrometry peptide feature detection with ion mobility support. https://doi.org/10.1002/rcm.9045

Installation
-------------
Using the pip:

    pip install biosaur2
    

Links
-----

- GitHub repo & issue tracker: https://github.com/markmipt/biosaur2
- Mailing list: markmipt@gmail.com
